@@ -29,7 +29,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>
 '''
-__version__ = '1.1.0'
+__version__ = '1.2.0'
 __author__ = 'Stephen B. Murray <sbm199@gmail.com>'
 
 import datetime
@@ -359,23 +359,25 @@ def parse_val(returned_data):
     continent = returned_data['SiteRep']['DV']['Location']['continent']
     lat = returned_data['SiteRep']['DV']['Location']['lat']
     lon = returned_data['SiteRep']['DV']['Location']['lon']
+    elevation = returned_data['SiteRep']['DV']['Location']['elevation']
     dtype = returned_data['SiteRep']['DV']['type']
     data_date = returned_data['SiteRep']['DV']['dataDate']
     data_key = {i['name']: {'text': i['$'], 'units': i['units']} for i in returned_data['SiteRep']['Wx']['Param']}
     data = []
     for weather in _weather_dict_gen(returned_data):
         data.append(weather)
-    return Weather(ident, name, country, continent, lat, lon, dtype, data_date, data)
+    return Weather(ident, name, country, continent, lat, lon, elevation, dtype, data_date, data)
 
 class Weather():
     '''A hold-all for returned weather data, including associated metadata.'''
-    def __init__(self, ident, name, country, continent, lat, lon, dtype, data_date, data):
+    def __init__(self, ident, name, country, continent, lat, lon, elevation, dtype, data_date, data):
         self.ident = ident
         self.name = name
         self.country = country
         self.continent = continent
         self.lat = float(lat)
         self.lon = float(lon)
+        self.elevation = float(elevation)
         self.dtype = dtype
         self.data_date = data_date
-        self.data = data
\ No newline at end of file
+        self.data = data
